

# Module hex_api_user #
* [Function Index](#index)
* [Function Details](#functions)

<a name="index"></a>

## Function Index ##


<table width="100%" border="1" cellspacing="0" cellpadding="2" summary="function index"><tr><td valign="top"><a href="#create-4">create/4</a></td><td>
Creates a new user account.</td></tr><tr><td valign="top"><a href="#get-2">get/2</a></td><td>
Gets a user.</td></tr><tr><td valign="top"><a href="#me-1">me/1</a></td><td>
Gets the authenticated user.</td></tr><tr><td valign="top"><a href="#reset_password-2">reset_password/2</a></td><td>
Resets the user's password.</td></tr></table>


<a name="functions"></a>

## Function Details ##

<a name="create-4"></a>

### create/4 ###

<pre><code>
create(Config::<a href="hex_core.md#type-config">hex_core:config()</a>, Username::binary(), Password::binary(), Email::binary()) -&gt; <a href="hex_api.md#type-response">hex_api:response()</a>
</code></pre>
<br />

Creates a new user account.

Examples:

```
  > hex_api_user:create(hex_core:default_config(), <<"user">>, <<"hunter42">>, <<"user@example.com">>).
  {ok, {201, ..., #{
       <<"email">> => <<"user@example.com">>,
       <<"full_name">> => <<"John Doe">>,
       <<"handles">> => #{...},
       <<"inserted_at">> => <<"2014-04-21T17:20:12Z">>,
       <<"level">> => <<"full">>,
       <<"updated_at">> => <<"2019-08-04T19:28:05Z">>,
       <<"url">> => <<"https://hex.pm/api/users/user">>,
       <<"username">> => <<"user">>
       }}}
```

<a name="get-2"></a>

### get/2 ###

<pre><code>
get(Config::<a href="hex_core.md#type-config">hex_core:config()</a>, Username::binary()) -&gt; <a href="hex_api.md#type-response">hex_api:response()</a>
</code></pre>
<br />

Gets a user.

Examples:

```
  > hex_api_user:get(hex_core:default_config()).
  {ok, {200, ..., #{
       <<"email">> => <<"user@example.com">>,
       <<"full_name">> => <<"John Doe">>,
       <<"handles">> => #{...},
       <<"inserted_at">> => <<"2014-04-21T17:20:12Z">>,
       <<"level">> => <<"full">>,
       <<"updated_at">> => <<"2019-08-04T19:28:05Z">>,
       <<"url">> => <<"https://hex.pm/api/users/user">>,
       <<"username">> => <<"user">>
       }}}
```

<a name="me-1"></a>

### me/1 ###

<pre><code>
me(Config::<a href="hex_core.md#type-config">hex_core:config()</a>) -&gt; <a href="hex_api.md#type-response">hex_api:response()</a>
</code></pre>
<br />

Gets the authenticated user.

Examples:

```
  > hex_api_user:me(hex_core:default_config()).
  {ok, {200, ..., #{
       <<"email">> => <<"user@example.com">>,
       <<"full_name">> => <<"John Doe">>,
       <<"handles">> => #{...},
       <<"inserted_at">> => <<"2014-04-21T17:20:12Z">>,
       <<"level">> => <<"full">>,
       <<"updated_at">> => <<"2019-08-04T19:28:05Z">>,
       <<"url">> => <<"https://hex.pm/api/users/user">>,
       <<"username">> => <<"user">>
       }}}
```

<a name="reset_password-2"></a>

### reset_password/2 ###

<pre><code>
reset_password(Config::<a href="hex_core.md#type-config">hex_core:config()</a>, Username::binary()) -&gt; <a href="hex_api.md#type-response">hex_api:response()</a>
</code></pre>
<br />

Resets the user's password.

Examples:

```
  > hex_api_user:reset_password(hex_core:default_config(), <<"user">>).
  {ok, {204, ..., nil}}
```

