

# Module hex_repo #
* [Function Index](#index)
* [Function Details](#functions)

<a name="index"></a>

## Function Index ##


<table width="100%" border="1" cellspacing="0" cellpadding="2" summary="function index"><tr><td valign="top"><a href="#get_names-1">get_names/1</a></td><td>
Gets names resource from the repository.</td></tr><tr><td valign="top"><a href="#get_package-2">get_package/2</a></td><td>
Gets package resource from the repository.</td></tr><tr><td valign="top"><a href="#get_tarball-3">get_tarball/3</a></td><td>
Gets tarball from the repository.</td></tr><tr><td valign="top"><a href="#get_versions-1">get_versions/1</a></td><td>
Gets versions resource from the repository.</td></tr></table>


<a name="functions"></a>

## Function Details ##

<a name="get_names-1"></a>

### get_names/1 ###

`get_names(Config) -> any()`

Gets names resource from the repository.

Examples:

```
  > hex_repo:get_names(hex_core:default_config()).
  {ok, {200, ...,
      [
          #{name => <<"package1">>},
          #{name => <<"package2">>},
      ]}}
```

<a name="get_package-2"></a>

### get_package/2 ###

`get_package(Config, Name) -> any()`

Gets package resource from the repository.

Examples:

```
  > hex_repo:get_package(hex_core:default_config(), <<"package1">>).
  {ok, {200, ...,
      {
          #{checksum => ..., version => <<"0.5.0">>, dependencies => []},
          #{checksum => ..., version => <<"1.0.0">>, dependencies => [
              #{package => <<"package2">>, optional => true, requirement => <<"~> 0.1">>}
          ]},
      ]}}
```

<a name="get_tarball-3"></a>

### get_tarball/3 ###

`get_tarball(Config, Name, Version) -> any()`

Gets tarball from the repository.

Examples:

```
  > {ok, {200, _, Tarball}} = hex_repo:get_tarball(<<"package1">>, <<"1.0.0">>, hex_core:default_config()),
  > {ok, #{metadata := Metadata}} = hex_tarball:unpack(Tarball, memory).
```

<a name="get_versions-1"></a>

### get_versions/1 ###

`get_versions(Config) -> any()`

Gets versions resource from the repository.

Examples:

```
  > hex_repo:get_versions(Config).
  {ok, {200, ...,
      [
          #{name => <<"package1">>, retired => [],
            versions => [<<"1.0.0">>]},
          #{name => <<"package2">>, retired => [<<"0.5.0>>"],
            versions => [<<"0.5.0">>, <<"1.0.0">>]},
      ]}}
```

